@@ -2,25 +2,19 @@
 svymean_dalen <- function(x, design, censoring, type = "Z2", na.rm = FALSE,
                           verbose = TRUE, ...)
 {
-    if (!is.language(x))
-        stop("Argument 'x' must be a formula object\n", call. = FALSE)
     dat <- .check_formula(x, design, na.rm)
     # in the presence of NA's
     if (dat$failure)
         return(.new_svystat_rob("mean", dat$yname, paste0("Dalen ", type,
-            " estimator (censored at ", censoring, ")"), dat$domain,
-            dat$design, match.call(), "dalen", censoring = censoring))
+            " estimator (censored at ", censoring, ")"), dat$design,
+            match.call(), "dalen", censoring = censoring))
 
-    # population- vs. domain-level estimate
-    res <- if (dat$domain)
-        weighted_mean_dalen(dat$y[dat$in_domain], dat$w[dat$in_domain],
-                            censoring, type, TRUE, FALSE, verbose)
-    else
-        weighted_mean_dalen(dat$y, dat$w, censoring, type, TRUE, FALSE,
+    # population- vs. domain-level estimate (matters for calibrated designs)
+    res <- weighted_mean_dalen(dat$y, dat$w, censoring, type, TRUE, FALSE,
                             verbose)
     # influence function
-    infl <- if (dat$domain) {
-        tmp <- numeric(dat$n)
+    infl <- if (dat$calibrated) {
+        tmp <- numeric(length(dat$in_domain))
         tmp[dat$in_domain] <- (res$robust$xw - res$model$w * res$estimate) /
             sum(res$model$w)
         tmp
@@ -34,7 +28,6 @@ svymean_dalen <- function(x, design, censoring, type = "Z2", na.rm = FALSE,
                               postStrata = design$postStrata)
     # return
     names(res$estimate) <- dat$yname
-    res$estimator$domain <- dat$domain
     res$design <- dat$design
     res$call <- match.call()
     class(res) <- "svystat_rob"
@@ -44,25 +37,19 @@ svymean_dalen <- function(x, design, censoring, type = "Z2", na.rm = FALSE,
 svytotal_dalen <- function(x, design, censoring, type = "Z2", na.rm = FALSE,
                            verbose = TRUE, ...)
 {
-    if (!is.language(x))
-        stop("Argument 'x' must be a formula object\n", call. = FALSE)
     dat <- .check_formula(x, design, na.rm)
     # in the presence of NA's
     if (dat$failure)
         return(.new_svystat_rob("total", dat$yname, paste0("Dalen ", type,
-            " estimator (censored at ", censoring, ")"), dat$domain,
-            dat$design, match.call(), "dalen", censoring = censoring))
+            " estimator (censored at ", censoring, ")"), dat$design,
+            match.call(), "dalen", censoring = censoring))
 
-    # population- vs. domain-level estimate
-    res <- if (dat$domain)
-        weighted_total_dalen(dat$y[dat$in_domain], dat$w[dat$in_domain],
-                             censoring, type, TRUE, FALSE, verbose)
-    else
-        weighted_total_dalen(dat$y, dat$w, censoring, type, TRUE, FALSE,
-                             verbose)
+    # population- vs. domain-level estimate (matters for calibrated designs)
+    res <- weighted_total_dalen(dat$y, dat$w, censoring, type, TRUE, FALSE,
+                                verbose)
     # influence function
-    infl <- if (dat$domain) {
-        tmp <- numeric(dat$n)
+    infl <- if (dat$calibrated) {
+        tmp <- numeric(length(dat$in_domain))
         tmp[dat$in_domain] <- res$robust$xw
         tmp
     } else {
@@ -75,7 +62,6 @@ svytotal_dalen <- function(x, design, censoring, type = "Z2", na.rm = FALSE,
                               design$fpc, postStrata = design$postStrata)
     # return
     names(res$estimate) <- dat$yname
-    res$estimator$domain <- dat$domain
     res$design <- dat$design
     res$call <- match.call()
     class(res) <- "svystat_rob"
